==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/OnCollapsedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnCollapsedEventArgsDescription } from "./OnCollapsedEventArgsDescription";
/**
 * @hidden
 */
export let OnCollapsedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class OnCollapsedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (OnCollapsedEventArgsDescriptionMetadata.a == null) {
                OnCollapsedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OnCollapsedEventArgsDescriptionMetadata.c(OnCollapsedEventArgsDescriptionMetadata.a);
            }
            if (a.k(OnCollapsedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(OnCollapsedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            OnCollapsedEventArgsDescriptionMetadata.b(a);
            a.ad("OnCollapsedEventArgs", () => new OnCollapsedEventArgsDescription());
            a.ac("OnCollapsedEventArgs", OnCollapsedEventArgsDescriptionMetadata.a);
        }
    }
    OnCollapsedEventArgsDescriptionMetadata.$t = markType(OnCollapsedEventArgsDescriptionMetadata, 'OnCollapsedEventArgsDescriptionMetadata');
    OnCollapsedEventArgsDescriptionMetadata.a = null;
    return OnCollapsedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/OnCollapsedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnCollapsedEventArgsDescription } from "./OnCollapsedEventArgsDescription";
/**
 * @hidden
 */
export let OnCollapsedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class OnCollapsedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (OnCollapsedEventArgsDescriptionMetadata.a == null) {
                OnCollapsedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OnCollapsedEventArgsDescriptionMetadata.c(OnCollapsedEventArgsDescriptionMetadata.a);
            }
            if (a.k(OnCollapsedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(OnCollapsedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            OnCollapsedEventArgsDescriptionMetadata.b(a);
            a.ae("OnCollapsedEventArgs", () => new OnCollapsedEventArgsDescription());
            a.ad("OnCollapsedEventArgs", OnCollapsedEventArgsDescriptionMetadata.a);
        }
    }
    OnCollapsedEventArgsDescriptionMetadata.$t = markType(OnCollapsedEventArgsDescriptionMetadata, 'OnCollapsedEventArgsDescriptionMetadata');
    OnCollapsedEventArgsDescriptionMetadata.a = null;
    return OnCollapsedEventArgsDescriptionMetadata;
})();
